# athena2pd
[![](https://img.shields.io/badge/python-3.6+-blue.svg)](https://www.python.org/download/releases/3.6.0/)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)


athena2pd (Amazon Athena to Pandas Dataframe)

## Installation
Use the package manager [pip](https://pip.pypa.io/en/stable/) to install athena2pd.

```bash
pip install athena2pd
```

## Usage
```python
import athena2pd

athena2pd.hello()   # Returns 'Hello World!'
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License

[MIT](LICENSE)